@@ -1,5 +1,5 @@
 import logging
-import os
+import os, sys
 
 
 ROOT_PATH=__path__[0]
@@ -17,6 +17,10 @@ dlogf_formatter=logging.Formatter('%(asctime)s - %(levelname)s : %(message)s')
 dlogf.setFormatter(dlogf_formatter)
 dlog.addHandler(dlogf)
 
+dlog_stdout=logging.StreamHandler(sys.stdout)
+dlog_stdout.setFormatter(dlogf_formatter)
+dlog.addHandler(dlog_stdout)
+
 __author__    = "DeepModeling Team"
 __copyright__ = "Copyright 2019"
 __status__    = "Development"
