@@ -20,7 +20,11 @@ script_template="""\
 script_env_template="""
 export REMOTE_ROOT={remote_root}
 test $? -ne 0 && exit 1
+
+{module_unload_part}
+{module_load_part}
 {source_files_part}
+{export_envs_part}
 """
 
 script_command_template="""
@@ -92,7 +96,7 @@ class Machine(object):
         try:
             machine_class = cls.subclasses_dict[batch_type]
         except KeyError as e:
-            print('debug:batch_type;subclasses_dict', batch_type, cls.subclasses_dict)
+            dlog.error(f"KeyError:batch_type; cls.subclasses_dict:{cls.subclasses_dict}; batch_type:{batch_type};")
             raise e
         context = BaseContext.load_from_dict(machine_dict)
         machine = machine_class(context=context)
@@ -153,14 +157,34 @@ class Machine(object):
 
     def gen_script_env(self, job):
         source_files_part = ""
+
+        module_unload_part = ""
+        module_unload_list = job.resources.module_unload_list
+        for ii in module_unload_list:
+            module_unload_part += f"module unload {ii}\n"
+
+        module_load_part = ""
+        module_list = job.resources.module_list
+        for ii in module_list:
+            module_load_part += f"module load {ii}\n"
+        
         source_list = job.resources.source_list
         for ii in source_list:
-            line = "{ source %s \n }" % ii
+            line = "{ source %s; } \n" % ii
             source_files_part += line
 
+        export_envs_part = ""
+        envs = job.resources.envs
+        for k,v in envs.items():
+            export_envs_part += f"export {k}={v}\n"
+
         script_env = script_env_template.format(
             remote_root=self.context.remote_root,
-            source_files_part=source_files_part)
+            module_unload_part=module_unload_part,
+            module_load_part=module_load_part,
+            source_files_part=source_files_part,
+            export_envs_part=export_envs_part,
+        )
         return script_env
 
     def gen_script_command(self, job):
@@ -234,6 +258,7 @@ class Machine(object):
         doc_local_root = 'The dir where the tasks and relating files locate. Typically the project dir.'
         doc_remote_root = 'The dir where the tasks are executed on the remote machine. Only needed when context is not lazy-local.'
         doc_remote_profile = 'The information used to maintain the connection with remote machine. Only needed when context is ssh.'
+        doc_clean_asynchronously = 'Clean the remote directory asynchronously after the job finishes.'
 
         remote_profile_format = SSHSession.arginfo()
         remote_profile_format.name = "remote_profile"
@@ -245,6 +270,7 @@ class Machine(object):
             Argument("local_root", str, optional=False, doc=doc_local_root),
             Argument("remote_root", str, optional=True, doc=doc_remote_root),
             remote_profile_format,
+            Argument("clean_asynchronously", bool, optional=True, default=False, doc=doc_clean_asynchronously),
         ]
 
         machine_format = Argument("machine", dict, machine_args)
