@@ -11,8 +11,7 @@ slurm_script_header_template="""\
 {slurm_nodes_line}
 {slurm_ntasks_per_node_line}
 {slurm_number_gpu_line}
-{slurm_partition_line}
-"""
+{slurm_partition_line}"""
 
 class Slurm(Machine):
     def gen_script(self, job):
@@ -55,9 +54,9 @@ class Slurm(Machine):
                 raise RuntimeError\
                     ("status command squeue fails to execute\nerror message:%s\nreturn code %d\n" % (err_str, ret))
         subret = (stdout.readlines())
-        # Submitted batch job 293859
+        # Submitted batch job 293859 on cluster faculty
         assert subret[0].startswith('Submitted'), f"Error when submiitting job to slurm system.subret:{subret}"
-        job_id = subret[0].split()[-1]
+        job_id = str(int(subret[0].split()[3]))
         self.context.write_file(job_id_name, job_id)        
         return job_id
 
@@ -102,7 +101,8 @@ class Slurm(Machine):
         elif status_word in ["CG"] :
             return JobStatus.completing
         elif status_word in ["C","E","K","BF","CA","CD","F","NF","PR","SE","ST","TO"] :
-            if self.check_finish_tag(job) :
+            if self.check_finish_tag(job):
+                dlog.info(f"job: {job.job_hash} {job.job_id} finished")
                 return JobStatus.finished
             else :
                 return JobStatus.terminated
@@ -111,5 +111,4 @@ class Slurm(Machine):
         
     def check_finish_tag(self, job):
         job_tag_finished = job.job_hash + '_job_tag_finished'
-        print('job finished: ',job.job_id, job_tag_finished)
         return self.context.check_file_exists(job_tag_finished)
