@@ -5,7 +5,7 @@ from typing import SupportsRound
 
 from dargs.dargs import Argument
 from dpdispatcher.JobStatus import JobStatus
-from dpdispatcher import dlog, machine
+from dpdispatcher import dlog
 from hashlib import sha1
 # from dpdispatcher.slurm import SlurmResources
 #%%
@@ -47,8 +47,6 @@ class Submission(object):
         self.backward_common_files = backward_common_files
 
         self.submission_hash = None
-        # print('Submission.__init__:task_list', task_list)
-        # print('empty_list:', [])
         # warning: can not remote .copy() or there will be bugs
         # self.belonging_tasks = task_list
         self.belonging_tasks = task_list.copy()
@@ -63,8 +61,6 @@ class Submission(object):
         """When check whether the two submission are equal,
         we disregard the runtime infomation(job_state, job_id, fail_count) of the submission.belonging_jobs.
         """
-        # print('submission.__eq__()  self', self.serialize(if_static=True))
-        # print('submission.__eq__() other', other.serialize(if_static=True))
         return self.serialize(if_static=True) == other.serialize(if_static=True)
 
     @classmethod
@@ -109,7 +105,6 @@ class Submission(object):
         submission_dict['forward_common_files'] = self.forward_common_files
         submission_dict['backward_common_files'] = self.backward_common_files
         submission_dict['belonging_jobs'] = [ job.serialize(if_static=if_static) for job in self.belonging_jobs]
-        # print('&&&&&&&&', submission_dict['belonging_jobs'] )
         return submission_dict
 
     def register_task(self, task):
@@ -117,7 +112,6 @@ class Submission(object):
             raise RuntimeError("Not allowed to register tasks after generating jobs."
                     "submission hash error {self}".format(self))
         self.belonging_tasks.append(task)
-        # self.belonging_tasks = task
 
     def register_task_list(self, task_list):
         if self.belonging_jobs:
@@ -155,10 +149,10 @@ class Submission(object):
             self.generate_jobs()
         self.try_recover_from_json()
         if self.check_all_finished():
-            print('debug:check_all_finished: True')
+            dlog.info('info:check_all_finished: True')
             pass
         else:
-            print('debug:check_all_finished: False')
+            dlog.info('info:check_all_finished: False')
             self.upload_jobs()
             self.handle_unexpected_submission_state()
             self.submission_to_json()
@@ -214,7 +208,7 @@ class Submission(object):
         """
         for job in self.belonging_jobs:
             job.get_job_state()
-            print('debug:get_submission_state: job: ', job.job_hash, job.job_id, job.job_state)
+            dlog.debug(f"debug:get_submission_state: job: {job.job_hash}, {job.job_id}, {repr(job.job_state)}")
         # self.submission_to_json()
 
     def handle_unexpected_submission_state(self):
@@ -226,12 +220,14 @@ class Submission(object):
         for job in self.belonging_jobs:
             job.handle_unexpected_job_state()
 
-    def submit_submission(self):
-        """submit the job belonging to the submission.
-        """
-        for job in self.belonging_jobs:
-            job.submit_job()
-        self.get_submission_state()
+    # not used here, submitting job is in handle_unexpected_submission_state.
+
+    # def submit_submission(self):
+    #     """submit the job belonging to the submission.
+    #     """
+    #     for job in self.belonging_jobs:
+    #         job.submit_job()
+    #     self.get_submission_state()
 
     def check_all_finished(self):
         """check whether all the jobs in the submission.
@@ -241,8 +237,6 @@ class Submission(object):
         This method will not handle unexpected job state in the submission.
         """
         self.get_submission_state()
-        # print('debug:***', [job.job_state for job in self.belonging_jobs])
-        # print('debug:***', [job for job in self.belonging_jobs])
         if any( (job.job_state in  [JobStatus.terminated, JobStatus.unknown] ) for job in self.belonging_jobs):
             self.submission_to_json()
         if any( (job.job_state in  [JobStatus.running,
@@ -278,7 +272,6 @@ class Submission(object):
         for ii in random_task_index_ll:
             job_task_list = [ self.belonging_tasks[jj] for jj in ii ]
             job = Job(job_task_list=job_task_list, machine=self.machine, resources=copy.deepcopy(self.resources))
-            # print('generate_jobs', ii, job)
             self.belonging_jobs.append(job)
 
         if self.machine is not None:
@@ -299,8 +292,7 @@ class Submission(object):
         self.machine.context.clean()
 
     def submission_to_json(self):
-        # print('~~~~,~~~', self.serialize())
-        self.get_submission_state()
+        # self.get_submission_state()
         write_str = json.dumps(self.serialize(), indent=4, default=str)
         submission_file_name = "{submission_hash}.json".format(submission_hash=self.submission_hash)
         self.machine.context.write_file(submission_file_name, write_str=write_str)
@@ -411,6 +403,27 @@ class Task(object):
         # task_dict['task_need_resources'] = self.task_need_resources
         return task_dict
 
+    @staticmethod
+    def arginfo():
+        doc_command = 'A command to be executed of this task. The expected return code is 0.'
+        doc_task_work_path = 'The dir where the command to be executed.'
+        doc_forward_files = 'The files to be uploaded in task_work_path before the task exectued.'
+        doc_backward_files = 'The files to be download to local_root in task_work_path after the task finished'
+        doc_outlog = 'The out log file name. redirect from stdout'
+        doc_errlog = 'The err log file name. redirect from stderr'
+
+        task_args = [
+            Argument("command", str, optional=False, doc=doc_command),
+            Argument("task_work_path", str, optional=False, doc=doc_task_work_path),
+            Argument("forward_files", list, optional=False, doc=doc_forward_files, default=[]),
+            Argument("backward_files", list, optional=False, doc=doc_backward_files, default=[]),
+            Argument("outlog", [None, str], optional=False, doc=doc_outlog, default='log'),
+            Argument("errlog", [None, str], optional=False, doc=doc_errlog, default='err'),
+        ]
+        task_format = Argument("task", dict, task_args)
+        return task_format
+
+
 class Job(object):
     """Job is generated by Submission automatically.
     A job ususally has many tasks and it may request computing resources from job scheduler systems.
@@ -492,7 +505,7 @@ class Job(object):
         -----
         this method will not submit or resubmit the jobs if the job is unsubmitted.
         """
-        print('debug:self.machine',self.machine)
+        dlog.debug(f"debug:query database; self.job_hash:{self.job_hash}; self.job_id:{self.job_id}")
         job_state = self.machine.check_status(self)
         self.job_state = job_state
 
@@ -503,7 +516,7 @@ class Job(object):
             raise RuntimeError("job_state for job {job} is unknown".format(job=self))
 
         if job_state == JobStatus.terminated:
-            print("job: {job_hash} terminated; restarting job".format(job_hash=self.job_hash))
+            dlog.info(f"job: {self.job_hash} terminated; restarting job")
             if self.fail_count > 3:
                 raise RuntimeError("job:job {job} failed 3 times".format(job=self))
             self.fail_count += 1
@@ -511,11 +524,12 @@ class Job(object):
             self.get_job_state()
 
         if job_state == JobStatus.unsubmitted:
+            dlog.info(f"job: {self.job_hash} unsubmitted; submit it")
             if self.fail_count > 3:
                 raise RuntimeError("job:job {job} failed 3 times".format(job=self))
             # self.fail_count += 1
             self.submit_job()
-            print("job: {job_hash} submit; job_id is {job_id}".format(job_hash=self.job_hash, job_id=self.job_id))
+            dlog.info("job: {job_hash} submit; job_id is {job_id}".format(job_hash=self.job_hash, job_id=self.job_id))
             # self.get_job_state()
 
     def get_hash(self):
@@ -559,7 +573,6 @@ class Job(object):
             self.job_state = JobStatus.unsubmitted
 
     def job_to_json(self):
-        # print('~~~~,~~~', self.serialize())
         write_str = json.dumps(self.serialize(), indent=2, default=str)
         self.machine.context.write_file(self.job_hash + '_job.json', write_str=write_str)
 
@@ -603,7 +616,10 @@ class Resources(object):
                 custom_flags=[],
                 strategy=default_strategy,
                 para_deg=1,
+                module_unload_list=[],
+                module_list=[],
                 source_list=[],
+                envs={},
                 **kwargs):
         self.number_node = number_node
         self.cpu_per_node = cpu_per_node
@@ -615,7 +631,10 @@ class Resources(object):
         self.custom_flags = custom_flags
         self.strategy = strategy
         self.para_deg = para_deg
+        self.module_unload_list = module_unload_list
+        self.module_list = module_list
         self.source_list = source_list
+        self.envs = envs
         # self.if_cuda_multi_devices = if_cuda_multi_devices
 
         self.kwargs = kwargs
@@ -646,7 +665,10 @@ class Resources(object):
         resources_dict['custom_flags'] = self.custom_flags
         resources_dict['strategy'] = self.strategy
         resources_dict['para_deg'] = self.para_deg
+        resources_dict['module_unload_list'] = self.module_unload_list
+        resources_dict['module_list'] = self.module_list
         resources_dict['source_list'] = self.source_list
+        resources_dict['envs'] = self.envs
         resources_dict['kwargs'] = self.kwargs
         return resources_dict
 
@@ -661,7 +683,10 @@ class Resources(object):
                         custom_flags=resources_dict['custom_flags'],
                         strategy=resources_dict['strategy'],
                         para_deg=resources_dict['para_deg'],
+                        module_unload_list=resources_dict['module_unload_list'],
+                        module_list=resources_dict['module_list'],
                         source_list=resources_dict['source_list'],
+                        envs=resources_dict['envs'],
                         **resources_dict['kwargs'])
         return resources
 
@@ -687,7 +712,9 @@ class Resources(object):
         doc_custom_flags = 'The extra lines pass to job submitting script header'
         doc_para_deg = 'Decide how many tasks will be run in parallel.'
         doc_source_list = 'The env file to be sourced before the command execution.'
-        # doc_kwargs = 'extra key-value pair'
+        doc_module_unload_list = 'The modules to be unloaded on HPC system before submitting jobs'
+        doc_module_list = 'The modules to be loaded on HPC system before submitting jobs'
+        doc_envs = 'The environment variables to be exported on before submitting jobs'
 
         strategy_args = [
             Argument("if_cuda_multi_devices", bool, optional=True, default=True)
@@ -707,6 +734,9 @@ class Resources(object):
             strategy_format,
             Argument("para_deg", int, optional=True, doc=doc_para_deg, default=1),
             Argument("source_list", list, optional=True, doc=doc_source_list, default=[]),
+            Argument("module_unload_list", list, optional=True, doc=doc_module_unload_list, default=[]),
+            Argument("module_list", list, optional=True, doc=doc_module_list, default=[]),
+            Argument("envs", dict, optional=True, doc=doc_envs, default={}),
         ]
         resources_format = Argument("resources", dict, resources_args)
         return resources_format
