@@ -17,10 +17,14 @@ from dpdispatcher.shell import Shell
 from dpdispatcher.lsf import LSF
 
 from dpdispatcher.local_context import _identical_files
-from dpdispatcher.dp_cloud_server import DpCloudServer
-from dpdispatcher.dp_cloud_server_context import DpCloudServerContext
+try:
+    from dpdispatcher.dp_cloud_server import DpCloudServer
+    from dpdispatcher.dp_cloud_server_context import DpCloudServerContext
+except:
+    pass
 from dpdispatcher.submission import Submission, Job, Task, Resources
 from dpdispatcher.machine import Machine
+import dargs
 
 def setUpModule():
     os.chdir(os.path.abspath(os.path.dirname(__file__)))
